alfa: The alpha-transformation

View source: R/alfa.R

The alpha-transformationR Documentation

The \alpha-transformation

Description

The \alpha-transformation.

Usage

alfa(x, a, h = TRUE)

Arguments

x

A matrix with the compositional data.

a

The value of the power transformation, it has to be between -1 and 1. If zero values are present it has to be greater than 0. If \alpha=0 the isometric log-ratio transformation is applied.

h

A boolean variable. If is TRUE (default value) the multiplication with the Helmert sub-matrix will take place. When \alpha=0 and h = FALSE, the result is the centred log-ratio transformation (Aitchison, 1986). In general, when h = FALSE the resulting transformation maps the data onto a singualr space. The sum of the vectors is equal to 0. Hence, from the simplex constraint the data go to another constraint.

Details

The \alpha-transformation is applied to the compositional data.

Value

A list including:

sa

The logarithm of the Jacobian determinant of the \alpha-transformation. This is used in the "profile" function to speed up the computations.

aff

The \alpha-transformed data.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr and Giorgos Athineou <gioathineou@gmail.com>.

References

Tsagris M. and Stewart C. (2022). A Review of Flexible Transformations for Modeling Compositional Data. In Advances and Innovations in Statistics and Data Science, pp. 225–234. https://link.springer.com/chapter/10.1007/978-3-031-08329-7_10

Tsagris Michail and Stewart Connie (2020). A folded model for compositional data analysis. Australian and New Zealand Journal of Statistics, 62(2): 249-277. https://arxiv.org/pdf/1802.07330.pdf

Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf

Aitchison J. (1986). The statistical analysis of compositional data. Chapman & Hall.

See Also

alfainv, pivot, alfa.profile, alfa.tune a.est, alpha.mle, alr, bc, fp, green

Examples

x <- as.matrix(iris[, 1:4])
x <- x / rowSums(x)

Compositional documentation built on Sept. 15, 2026, 9:07 a.m.