| MLE of the folded model for a given value of alpha | R Documentation |
\alpha
MLE of the folded model for a given value of \alpha.
alpha.mle(x, a)
a.mle(a, x)
x |
A matrix with the compositional data. No zero vaues are allowed. |
a |
A value of |
This is a function for choosing or estimating the value of \alpha in the \alpha-folded
model (Tsagris and Stewart, 2020). It is called by a.est. The function alpha.mle()
had a bug which was noticed by Wang, Yu and Yu (2026) and it is now fixed. The function now returns
the correct log-likelihood and not the log-likelihood of the Q function in the EM algorithm.
Also, the case of negative or positive \alpha is being treated properly. The function a.mle()
returns the value of the Q function, deliberately, because it used as internal function in the
a.est function.
If "alpha.mle" is called, a list including:
iters |
The number of iterations the EM algorithm required. |
loglik |
The maximimized log-likelihood of the folded model. |
p |
The estimated probability inside the simplex of the |
mu |
The estimated mean vector of the |
su |
The estimated covariance matrix of the |
If "a.mle" is called, the log-likelihood is returned only.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Wang X., Yu L. and Yu, H. (2026). Data-driven small area estimation for compositional proportions based on parametric transformations. Statistical Methods & Applications, 1-41.
Tsagris M. and Stewart C. (2022). A Review of Flexible Transformations for Modeling Compositional Data. In Advances and Innovations in Statistics and Data Science, pp. 225–234. https://link.springer.com/chapter/10.1007/978-3-031-08329-7_10
Tsagris M. and Stewart C. (2020). A folded model for compositional data analysis. Australian and New Zealand Journal of Statistics, 62(2): 249-277. https://arxiv.org/pdf/1802.07330.pdf
Tsagris M.T., Preston S. and Wood A.T.A. (2011). A data-based power transformation for compositional data. In Proceedings of the 4th Compositional Data Analysis Workshop, Girona, Spain. https://arxiv.org/pdf/1106.1451.pdf
alfa.profile, alfa, alfainv, a.est
x <- rdiri(100, runif(4, 5, 8))
alpha.mle(x, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.