beta.reg: Beta regression

View source: R/beta.reg.R

Beta regressionR Documentation

Beta regression

Description

Beta regression.

Usage

beta.reg(y, x, xnew = NULL)
beta.reg.irls(y, x, xnew = NULL, tol = 1e-6, maxit = 100)

Arguments

y

The response variable. It must be a numerical vector with proportions excluding 0 and 1.

x

The indendent variable(s). It can be a vector, a matrix or a dataframe with continuous only variables, a data frame with mixed or only categorical variables.

xnew

If you have new values for the predictor variables (dataset) whose response values you want to predict insert them here.

tol

The tolerance value of the Fisher-scoring algorithm.

maxit

The maximum number of iterations the Fisher-scoring algorithm will perform.

Details

Beta regression is fitted. The beta.reg.irls() function implements the Fisher-scoring algorithm.

Value

A list including:

iters

The number of iterations the Fisher-scoring algorithm performed.

loglik

The log-likelihood of the regression model.

phi

The estimated precision parameter.

sephi

The standard erro of the precision parameter.

info

A matrix with the estimated regression parameters, their standard errors, Wald statistics and associated p-values.

est

The estimated values if xnew is not NULL.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Ferrari S.L.P. and Cribari-Neto F. (2004). Beta Regression for Modelling Rates and Proportions. Journal of Applied Statistics, 31(7): 799-815.

See Also

beta.est, propreg, diri.reg

Examples

y <- rbeta(300, 3, 5)
x <- matrix( rnorm(300 * 2), ncol = 2)
beta.reg(y, x)

Compositional documentation built on Sept. 15, 2026, 9:07 a.m.