bic.mixdiri: Dirichlet mixture model selection via BIC and ICL

View source: R/bic.mixdiri.R

Dirichlet mixture model selection via BIC and ICLR Documentation

Dirichlet mixture model selection via BIC and ICL

Description

Dirichlet mixture model selection via BIC and ICL.

Usage

bic.mixdiri(x, G = 5, tol = 1e-4, graph = FALSE)

Arguments

x

A matrix containing compositional data, no zero values are allowed.

G

The maximum number of clusters to be tested. Default value is 5.

tol

The tolerance value to terminate the EM algorithm.

graph

A boolean variable, TRUE or FALSE specifying whether a graph should be drawn or not.

Details

The function computes the BIC and ICL to decide on the optimal number of clusters when using Dirichlet mixtures.

Value

A plot of the ICL values and a list including:

bic

The BIC values for all the models tested.

icl

The ICL values for all the models tested.

runtime

The run time of the process.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Ryan P. Browne, Aisha ElSherbiny and Paul D. McNicholas (2018). mixture: Mixture Models for Clustering and Classification. R package version 1.5.

Ryan P. Browne and Paul D. McNicholas (2014). Estimating Common Principal Components in High Dimensions. Advances in Data Analysis and Classification, 8(2), 217-226.

Aitchison J. (1986). The statistical analysis of compositional data. Chapman & Hall.

See Also

mix.diri, rmixdiri, bic.mixcompnorm

Examples

x <- as.matrix( iris[, 1:3] )
x <- x / rowSums(x)
bic.mixdiri(x, G = 3)

Compositional documentation built on Aug. 21, 2026, 9:06 a.m.