mix.diri: Dirichlet mixture models for compositional data

View source: R/mix.diri.R

Dirichlet mixture models for compositional dataR Documentation

Dirichlet mixture models for compositional data

Description

Dirichlet mixture models for compositional data.

Usage

mix.diri(x, g, tol = 1e-4)

Arguments

x

A matrix with the compositional data.

g

How many clusters to create.

tol

The tolerance level indicating no further increase in the log-likelihood.

Details

A Dirichlet mixture model is fitted.

Value

A list including:

param

A matrix where each row corresponds to the mixing probability and the estimated parameters of each cluster.

loglik

The log-likelihood of the model.

probs

A vector with the probability of each observation belonging to each cluster.

est

The estimated cluster membership values.

iters

The number of iterations the EM algorithm performed.

runtime

The runtime of the algorithm.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Ryan P. Browne, Aisha ElSherbiny and Paul D. McNicholas (2015). R package mixture: Mixture Models for Clustering and Classification.

Aitchison J. (1986). The statistical analysis of compositional data. Chapman & Hall.

See Also

bic.mixdiri, rmixdiri, mix.compnorm

Examples


x <- as.matrix(iris[, 1:4])
x <- x/ rowSums(x)
mod <- mix.diri(x, 3)


Compositional documentation built on Aug. 21, 2026, 9:06 a.m.