| Dirichlet mixture models for compositional data | R Documentation |
Dirichlet mixture models for compositional data.
mix.diri(x, g, tol = 1e-4)
x |
A matrix with the compositional data. |
g |
How many clusters to create. |
tol |
The tolerance level indicating no further increase in the log-likelihood. |
A Dirichlet mixture model is fitted.
A list including:
param |
A matrix where each row corresponds to the mixing probability and the estimated parameters of each cluster. |
loglik |
The log-likelihood of the model. |
probs |
A vector with the probability of each observation belonging to each cluster. |
est |
The estimated cluster membership values. |
iters |
The number of iterations the EM algorithm performed. |
runtime |
The runtime of the algorithm. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Ryan P. Browne, Aisha ElSherbiny and Paul D. McNicholas (2015). R package mixture: Mixture Models for Clustering and Classification.
Aitchison J. (1986). The statistical analysis of compositional data. Chapman & Hall.
bic.mixdiri, rmixdiri, mix.compnorm
x <- as.matrix(iris[, 1:4])
x <- x/ rowSums(x)
mod <- mix.diri(x, 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.